summaryrefslogtreecommitdiffstats
path: root/win/qeventloopex.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'win/qeventloopex.cpp')
-rw-r--r--win/qeventloopex.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/win/qeventloopex.cpp b/win/qeventloopex.cpp
index da5eba60c..9db6bd133 100644
--- a/win/qeventloopex.cpp
+++ b/win/qeventloopex.cpp
@@ -263,7 +263,7 @@ void QEventLoopEx::unregisterSocketNotifier( TQSocketNotifier *notifier )
SetEvent(d->m_evPendingListEmpty);
list->remove(); // remove notifier found above
- if ( d->sn_highest == sockfd ) {// find highest fd
+ if ( d->sn_highest == sockfd ) {// tqfind highest fd
d->sn_highest = -1;
for ( int i=0; i<3; i++ ) {
if ( d->sn_vec[i].list && ! d->sn_vec[i].list->isEmpty() )
@@ -433,7 +433,7 @@ void QEventLoopEx::run()
if (WSAGetLastError() == WSAENOTSOCK) {
// it seems a socket notifier has a bad fd... find out
// which one it is and disable it
fd_set fdset;
struct timeval zerotm;
@@ -433,7 +433,7 @@ void QEventLoopEx::run()
if (WSAGetLastError() == WSAENOTSOCK) {
- // it seems a socket notifier has a bad fd... find out
+ // it seems a socket notifier has a bad fd... tqfind out
// which one it is and disable it
fd_set fdset;